@@ -19,11 +19,10 @@ from pathlib import Path
 from typing import Dict, List, Optional, Union
 
 import pybind11
-from ccimport import compat
-from ccimport import loader
+
+from ccimport import compat, loader
+from ccimport.buildtools.writer import build_simple_ninja, fill_build_flags
 from ccimport.source_iter import CppSourceIterator
-from ccimport.buildtools.writer import (build_simple_ninja,
-                                             fill_build_flags)
 from ccimport.utils import tempdir
 
 _PYBIND_COMMON_INCLUDES = [
@@ -34,6 +33,20 @@ _PYBIND_COMMON_INCLUDES = [
 ]
 
 
+def get_full_file_name(name, build_ctype):
+    lib_prefix = ""
+    if not compat.InWindows and build_ctype:
+        lib_prefix = "lib"
+    if not build_ctype:
+        lib_suffix = compat.get_extension_suffix()
+    else:
+        if compat.InWindows:
+            lib_suffix = ".dll"
+        else:
+            lib_suffix = ".so"
+    return lib_prefix + name + lib_suffix
+
+
 def ccimport(source_paths: List[Union[str, Path]],
              out_path: Union[str, Path],
              includes: Optional[List[Union[str, Path]]] = None,
@@ -113,18 +126,8 @@ def ccimport(source_paths: List[Union[str, Path]],
     python_includes = compat.get_pybind11_includes()
     includes.extend(python_includes)
 
-    target_filename = None
-    lib_prefix = ""
-    if not compat.InWindows and build_ctype:
-        lib_prefix = "lib"
-    if not build_ctype:
-        lib_suffix = compat.get_extension_suffix()
-        target_filename = lib_prefix + lib_name + lib_suffix
-    else:
-        if compat.InWindows:
-            lib_suffix = ".dll"
-        else:
-            lib_suffix = ".so"
+    target_filename = get_full_file_name(lib_name, build_ctype)
+
     build_dir = out_path.parent / "build"
     build_dir.mkdir(exist_ok=True)
     target_filename = build_simple_ninja(lib_name, build_dir, source_paths,
@@ -134,6 +137,11 @@ def ccimport(source_paths: List[Union[str, Path]],
     build_out_path = build_dir / target_filename
     out_path = out_path.parent / target_filename
     shutil.copy(build_out_path, out_path)
+    if compat.InWindows and build_ctype:
+        win_lib_file = build_out_path.parent / (build_out_path.stem + ".lib")
+        if win_lib_file.exists():
+            shutil.copy(win_lib_file, out_path.parent / win_lib_file.name)
+
     extension_path = str(out_path)
     if not disable_hash:
         with fake_out_as_hash.open("w") as f:
@@ -259,6 +267,8 @@ def autoimport(sources: List[Union[str, Path]],
                compile_options: Optional[List[str]] = None,
                link_options: Optional[List[str]] = None,
                std="c++14",
+               disable_hash=False,
+               load_library=True,
                additional_cflags: Optional[Dict[str, List[str]]] = None):
     sources = list(map(lambda p: Path(p).resolve(), sources))
     if includes is None:
@@ -311,6 +321,7 @@ def autoimport(sources: List[Union[str, Path]],
                        link_options,
                        std=std,
                        source_paths_for_hash=sources,
-                       disable_hash=False,
+                       disable_hash=disable_hash,
+                       load_library=load_library,
                        additional_cflags=additional_cflags)
         return mod
